@@ -5,7 +5,7 @@ use warnings;
 use lib 'lib';
 
 package File::Util;
-$File::Util::VERSION = '4.161200';
+$File::Util::VERSION = '4.161950';
 use File::Util::Definitions qw( :all );
 use File::Util::Interface::Modern qw( :all );
 
@@ -113,7 +113,9 @@ sub list_dir {
    my $dir  = shift @_;
    my $opts = ref $_[0] eq 'REF' ? ${ shift @_ } : $this->_remove_opts( \@_ );
 
-   my ( @dir_contents, $subdirs, $files );
+   my @dir_contents;
+
+   my ( $subdirs, $files ) = ( [], [] );
 
    my $abort_depth = $opts->{abort_depth};
 
@@ -2992,7 +2994,7 @@ File::Util - Easy, versatile, portable file handling
 
 =head1 VERSION
 
-version 4.161200
+version 4.161950
 
 =head1 DESCRIPTION
 
